@@ -137,8 +137,8 @@ class TemporaryUploadChunked(models.Model):
                                validators=[MinLengthValidator(22)])
     upload_dir = models.CharField(max_length=512, default=upload_id)
     last_chunk = models.IntegerField(default=0)
-    offset = models.IntegerField(default=0)
-    total_size = models.IntegerField(default=0)
+    offset = models.BigIntegerField(default=0)
+    total_size = models.BigIntegerField(default=0)
     upload_name = models.CharField(max_length=512, default='')
     upload_complete = models.BooleanField(default=False)
     last_upload_time = models.DateTimeField(auto_now=True)
